"""
Snail Core - System information collection and upload framework for Linux.

A modular framework for collecting system diagnostics and uploading them
to a custom endpoint, inspired by Red Hat's insights-core.
"""

__version__ = "0.5.3"
__author__ = "Sluggisty"

__all__ = ["__version__"]
